package com.example.demo.controller;

import com.example.demo.repository.TaskRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.thymeleaf.spring6.context.webflux.IReactiveDataDriverContextVariable;
import org.thymeleaf.spring6.context.webflux.ReactiveDataDriverContextVariable;

@Controller
@RequestMapping("/api")
public class TaskController {

    @Autowired
    private TaskRepository repository;

    /*
<ol>
<li>Maps an HTTP GET request to the <code>/tasks</code> URL path using the <code>@GetMapping</code> annotation.</li>
<li>Accepts a <code>Model</code> parameter named <code>model</code>. The <code>Model</code> interface is used for passing data between the controller and the view.</li>
<li>Retrieves a list of tasks from a repository using <code>repository.findAll()</code>.</li>
<li>Creates a reactive data driver context variable with the retrieved data and a streaming configuration (1 item at a time).</li>
<li>Adds the <code>tasks</code> attribute to the <code>Model</code> object, making the data available for the view.</li>
<li>Returns the string "index," indicating that the view named "index" should be rendered. The actual view resolution and rendering are handled by Spring MVC.</li>
</ol>
     */
    // http://localhost:9030/api/tasks
    @GetMapping("/tasks")
    public String index(final Model model) {

        IReactiveDataDriverContextVariable variable =
                new ReactiveDataDriverContextVariable(repository.findAll(), 1);

        model.addAttribute("tasks", variable);

        return "index";
    }
}
