package com.example.demo.repository;

import com.example.demo.entity.Task;
import org.springframework.stereotype.Repository;
import reactor.core.publisher.Flux;

import java.time.Duration;
import java.util.ArrayList;
import java.util.List;

@Repository
public class TaskRepository {

    private static final List<Task> tasks = new ArrayList<>();

    static {
        for (int i = 1; i <= 50; i++) {
            Task t = new Task();
            t.setId(i);
            t.setName("Task " + i);
            t.setCompleted(i % 2 == 0);
            tasks.add(t);
        }
    }

    public Flux<Task> findAll() {
        /*
<ol>
<li><code>Flux.fromIterable(tasks)</code>: This part creates a <code>Flux</code> by converting an iterable, in this case, the <code>tasks</code> collection, into a reactive stream. Each element of <code>tasks</code> becomes an item in the <code>Flux</code>.</li>
<li><code>.delayElements(Duration.ofSeconds(2))</code>: After creating the <code>Flux</code>, this part introduces a time delay of 2 seconds between emitting each element. This means that each item emitted by the <code>Flux</code> will be delayed by 2 seconds before being processed further or delivered downstream.</li>
</ol>
         */
        return Flux.fromIterable(tasks).delayElements(Duration.ofSeconds(2));
    }
}
